========
Overview
========

.. start-badges

.. list-table::
    :stub-columns: 1

    * - docs
      - |docs|
    * - tests
      - | |travis| |appveyor| |requires|
        | |codecov|
    * - package
      - | |version| |downloads| |wheel| |supported_versions| |supported_implementations|
        | |commits_since|

.. |docs| image:: https://readthedocs.org/projects/python-pysight/badge/?style=flat
    :target: https://readthedocs.org/projects/python-pysight
    :alt: Documentation Status

.. |travis| image:: https://travis-ci.org/HagaiHargil/python-pysight.svg?branch=master
    :alt: Travis-CI Build Status
    :target: https://travis-ci.org/HagaiHargil/python-pysight

.. |appveyor| image:: https://ci.appveyor.com/api/projects/status/github/HagaiHargil/python-pysight?branch=master&svg=true
    :alt: AppVeyor Build Status
    :target: https://ci.appveyor.com/project/HagaiHargil/python-pysight

.. |requires| image:: https://requires.io/github/HagaiHargil/python-pysight/requirements.svg?branch=master
    :alt: Requirements Status
    :target: https://requires.io/github/HagaiHargil/python-pysight/requirements/?branch=master

.. |codecov| image:: https://codecov.io/github/HagaiHargil/python-pysight/coverage.svg?branch=master
    :alt: Coverage Status
    :target: https://codecov.io/github/HagaiHargil/python-pysight

.. |version| image:: https://img.shields.io/pypi/v/pysight.svg
    :alt: PyPI Package latest release
    :target: https://pypi.python.org/pypi/pysight

.. |commits_since| image:: https://img.shields.io/github/commits-since/HagaiHargil/python-pysight/v0.5.10.svg
    :alt: Commits since latest release
    :target: https://github.com/HagaiHargil/python-pysight/compare/v0.5.10...master

.. |downloads| image:: https://img.shields.io/pypi/dm/pysight.svg
    :alt: PyPI Package monthly downloads
    :target: https://pypi.python.org/pypi/pysight

.. |wheel| image:: https://img.shields.io/pypi/wheel/pysight.svg
    :alt: PyPI Wheel
    :target: https://pypi.python.org/pypi/pysight

.. |supported_versions| image:: https://img.shields.io/pypi/pyversions/pysight.svg
    :alt: Supported versions
    :target: https://pypi.python.org/pypi/pysight

.. |supported_implementations| image:: https://img.shields.io/pypi/implementation/pysight.svg
    :alt: Supported implementations
    :target: https://pypi.python.org/pypi/pysight


.. end-badges

Create images from photon lists generated by a multiscaler.

* Free software: BSD license

* Created by `Pablo Blinder's Lab`_.

.. _Pablo Blinder's Lab: http://pblab.tau.ac.il/en/

Installation
============

.. include:: docs/installation.rst

Please refer to ``docs\installation.rst``.

Documentation
=============



https://python-pysight.readthedocs.io/

Development
===========

To run the all tests run::

    tox

Note, to combine the coverage data from all the tox environments run:

.. list-table::
    :widths: 10 90
    :stub-columns: 1

    - - Windows
      - ::

            set PYTEST_ADDOPTS=--cov-append
            tox

    - - Other
      - ::

            PYTEST_ADDOPTS=--cov-append tox
